@@ -1,5 +1,4 @@
-package # hide from PAUSE
-    TestApp::View::Mason::Match;
+package TestApp::View::Mason::Match;
 
 use strict;
 use warnings;
